package org.jeecg.modules.employCategory.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.employCategory.entity.EmployCategory;
import org.jeecg.modules.employCategory.service.IEmployCategoryService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 分类表
 * @Author: jeecg-boot
 * @Date:   2025-02-26
 * @Version: V1.0
 */
@Api(tags="分类表")
@RestController
@RequestMapping("/employCategory/employCategory")
@Slf4j
public class EmployCategoryController extends JeecgController<EmployCategory, IEmployCategoryService>{
	@Autowired
	private IEmployCategoryService employCategoryService;
	
	/**
	 * 分页列表查询
	 *
	 * @param employCategory
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "分类表-分页列表查询")
	@ApiOperation(value="分类表-分页列表查询", notes="分类表-分页列表查询")
	@GetMapping(value = "/rootList")
	public Result<IPage<EmployCategory>> queryPageList(EmployCategory employCategory,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		String hasQuery = req.getParameter("hasQuery");
        if(hasQuery != null && "true".equals(hasQuery)){
            QueryWrapper<EmployCategory> queryWrapper =  QueryGenerator.initQueryWrapper(employCategory, req.getParameterMap());
            List<EmployCategory> list = employCategoryService.queryTreeListNoPage(queryWrapper);
            IPage<EmployCategory> pageList = new Page<>(1, 10, list.size());
            pageList.setRecords(list);
            return Result.OK(pageList);
        }else{
            String parentId = employCategory.getPid();
            if (oConvertUtils.isEmpty(parentId)) {
                parentId = "0";
            }
            employCategory.setPid(null);
            QueryWrapper<EmployCategory> queryWrapper = QueryGenerator.initQueryWrapper(employCategory, req.getParameterMap());
            // 使用 eq 防止模糊查询
            queryWrapper.eq("pid", parentId);
            Page<EmployCategory> page = new Page<EmployCategory>(pageNo, pageSize);
            IPage<EmployCategory> pageList = employCategoryService.page(page, queryWrapper);
            return Result.OK(pageList);
        }
	}

	 /**
      * 获取子数据
      * @param employCategory
      * @param req
      * @return
      */
	//@AutoLog(value = "分类表-获取子数据")
	@ApiOperation(value="分类表-获取子数据", notes="分类表-获取子数据")
	@GetMapping(value = "/childList")
	public Result<IPage<EmployCategory>> queryPageList(EmployCategory employCategory,HttpServletRequest req) {
		QueryWrapper<EmployCategory> queryWrapper = QueryGenerator.initQueryWrapper(employCategory, req.getParameterMap());
		List<EmployCategory> list = employCategoryService.list(queryWrapper);
		IPage<EmployCategory> pageList = new Page<>(1, 10, list.size());
        pageList.setRecords(list);
		return Result.OK(pageList);
	}

    /**
      * 批量查询子节点
      * @param parentIds 父ID（多个采用半角逗号分割）
      * @return 返回 IPage
      * @param parentIds
      * @return
      */
	//@AutoLog(value = "分类表-批量获取子数据")
    @ApiOperation(value="分类表-批量获取子数据", notes="分类表-批量获取子数据")
    @GetMapping("/getChildListBatch")
    public Result getChildListBatch(@RequestParam("parentIds") String parentIds) {
        try {
            QueryWrapper<EmployCategory> queryWrapper = new QueryWrapper<>();
            List<String> parentIdList = Arrays.asList(parentIds.split(","));
            queryWrapper.in("pid", parentIdList);
            List<EmployCategory> list = employCategoryService.list(queryWrapper);
            IPage<EmployCategory> pageList = new Page<>(1, 10, list.size());
            pageList.setRecords(list);
            return Result.OK(pageList);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return Result.error("批量查询子节点失败：" + e.getMessage());
        }
    }
	
	/**
	 *   添加
	 *
	 * @param employCategory
	 * @return
	 */
	@AutoLog(value = "分类表-添加")
	@ApiOperation(value="分类表-添加", notes="分类表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody EmployCategory employCategory) {
		employCategoryService.addEmployCategory(employCategory);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param employCategory
	 * @return
	 */
	@AutoLog(value = "分类表-编辑")
	@ApiOperation(value="分类表-编辑", notes="分类表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody EmployCategory employCategory) {
		employCategoryService.updateEmployCategory(employCategory);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "分类表-通过id删除")
	@ApiOperation(value="分类表-通过id删除", notes="分类表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		employCategoryService.deleteEmployCategory(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "分类表-批量删除")
	@ApiOperation(value="分类表-批量删除", notes="分类表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.employCategoryService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "分类表-通过id查询")
	@ApiOperation(value="分类表-通过id查询", notes="分类表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<EmployCategory> queryById(@RequestParam(name="id",required=true) String id) {
		EmployCategory employCategory = employCategoryService.getById(id);
		if(employCategory==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(employCategory);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param employCategory
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, EmployCategory employCategory) {
		return super.exportXls(request, employCategory, EmployCategory.class, "分类表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
		return super.importExcel(request, response, EmployCategory.class);
    }

}
